@@ -2,7 +2,7 @@ use crate::model::duplicate::{Duplicate, Duplicates};
 use crate::model::hashed_file::{HashedFile, HashedFiles};
 use crate::model::line_range::LineRange;
 
-pub fn get_all_duplicates(files: HashedFiles) -> Duplicates {
+pub fn get_all_duplicates(minimum_successive_lines: usize, files: HashedFiles) -> Duplicates {
     let mut duplicates = vec![];
 
     let number_of_files = files.len();
@@ -10,6 +10,7 @@ pub fn get_all_duplicates(files: HashedFiles) -> Duplicates {
     for file_index_1 in 0..number_of_files {
         for file_index_2 in (file_index_1 + 1)..number_of_files {
             duplicates.extend(get_duplicates(
+                minimum_successive_lines,
                 files.get(file_index_1).unwrap(),
                 files.get(file_index_2).unwrap(),
             ));
@@ -19,9 +20,11 @@ pub fn get_all_duplicates(files: HashedFiles) -> Duplicates {
     duplicates
 }
 
-const MINIMUM_SUCCESSIVE_LINES: usize = 3;
-
-fn get_duplicates(file_1: &HashedFile, file_2: &HashedFile) -> Duplicates {
+fn get_duplicates(
+    minimum_successive_lines: usize,
+    file_1: &HashedFile,
+    file_2: &HashedFile,
+) -> Duplicates {
     let mut duplicates = vec![];
     let mut file_1_line_number = 1;
     let file_1_line_number_upper_range = file_1.number_of_lines + 1;
@@ -74,7 +77,7 @@ fn get_duplicates(file_1: &HashedFile, file_2: &HashedFile) -> Duplicates {
                     }
                 }
 
-                if (successive_file_1_line_number - file_1_start) >= MINIMUM_SUCCESSIVE_LINES {
+                if (successive_file_1_line_number - file_1_start) >= minimum_successive_lines {
                     // We have a successive match of at least MINIMUM_SUCCESSIVE_LINES
                     let file_1_end = successive_file_1_line_number - 1;
                     let file_1_line_range = LineRange {
