@@ -29,5 +29,10 @@ fn main() {
         arguments.minimum_successive_lines,
         hashed_files,
     );
-    crate::reporter::pretty_print_duplicates(indexed_files, duplicates);
+
+    if arguments.json {
+        crate::reporter::json_print_duplicates(duplicates);
+    } else {
+        crate::reporter::pretty_print_duplicates(indexed_files, duplicates);
+    }
 }
