@@ -4,8 +4,7 @@ use super::*;
 
 pub type Duplicates = Vec<Duplicate>;
 
-#[cfg_attr(test, derive(serde::Serialize))]
-#[derive(Debug)]
+#[derive(serde::Serialize)]
 pub struct Duplicate {
     pub file_1: Filename,
     pub file_1_line_range: LineRange,
