@@ -1,7 +1,6 @@
 use super::*;
 
-#[cfg_attr(test, derive(serde::Serialize))]
-#[derive(Debug)]
+#[derive(serde::Serialize)]
 pub struct LineRange {
     pub start: LineNumber,
     pub end: LineNumber,
