@@ -38,3 +38,9 @@ pub fn pretty_print_duplicates(indexed_files: IndexedFiles, duplicates: Duplicat
         println!();
     }
 }
+
+pub fn json_print_duplicates(duplicates: Duplicates) {
+    for duplicate in duplicates {
+        println!("{}", serde_json::to_string(&duplicate).unwrap());
+    }
+}
